Shared Perl source-file classification helpers.
These helpers provide one canonical definition for what constitutes a Perl source file across workspace discovery and runtime file operations.
Constants
- PERL_
SOURCE_ EXTENSIONS - Canonical Perl source file extensions.
Functions
- is_
perl_ source_ extension - Returns
trueifextensionis a recognized Perl source extension. - is_
perl_ source_ path - Returns
trueifpathpoints to a recognized Perl source file. - is_
perl_ source_ uri - Returns
trueifurior path-like string points to a Perl source file.